==> estateplat-common-1.2.4-20220622.062135-1050-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/DjfDjDbNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbNotNullDateAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

@XmlRootElement(name = "DJF_DJ_DB")
@Table(name = "DJF_DJ_DB")
public class DjfDjDbNew implements Serializable, AccessData {
    private String ywh;
    final static String ysdm = "6004040000";
    private String dbryxm;
    private Date dbsj;
    private String dbyj;
    private String czjg;
    private String qxdm;
    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }
    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "DBRYXM")
    public String getDbryxm() {
        return dbryxm;
    }

    public void setDbryxm(String dbryxm) {
        this.dbryxm = dbryxm;
    }
    @XmlAttribute(name = "DBSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getDbsj() {
        return dbsj;
    }

    public void setDbsj(Date dbsj) {
        this.dbsj = dbsj;
    }
    @XmlAttribute(name = "DBYJ")
    public String getDbyj() {
        return dbyj;
    }

    public void setDbyj(String dbyj) {
        this.dbyj = dbyj;
    }
    @XmlAttribute(name = "CZJG")
    public String getCzjg() {
        return czjg;
    }

    public void setCzjg(String czjg) {
        this.czjg = czjg;
    }
    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}

==> estateplat-common-1.2.4-20250919.082234-1309-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/DjfDjDbNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

@XmlRootElement(name = "DJF_DJ_DB")
@Table(name = "DJF_DJ_DB")
public class DjfDjDbNew implements Serializable, AccessData {
    private String ywh;
    final static String ysdm = "6004040000";
    private String dbryxm;
    private Date dbsj;
    private String dbyj;
    private String czjg;
    private String qxdm;
    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }
    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "DBRYXM")
    public String getDbryxm() {
        return dbryxm;
    }

    public void setDbryxm(String dbryxm) {
        this.dbryxm = dbryxm;
    }
    @XmlAttribute(name = "DBSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getDbsj() {
        return dbsj;
    }

    public void setDbsj(Date dbsj) {
        this.dbsj = dbsj;
    }
    @XmlAttribute(name = "DBYJ")
    public String getDbyj() {
        return dbyj;
    }

    public void setDbyj(String dbyj) {
        this.dbyj = dbyj;
    }
    @XmlAttribute(name = "CZJG")
    public String getCzjg() {
        return czjg;
    }

    public void setCzjg(String czjg) {
        this.czjg = czjg;
    }
    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}
